/*
 * X11 GUI for slide puzzle game
 * Copyright © 2022 Nick Bowler
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef RRACE_MOTIF_H_
#define RRACE_MOTIF_H_

#include <inttypes.h>
#include "ewmhicon.h"
#include "colour.h"
#include "game.h"

struct app_state {
	struct board board;

	Widget game, goal;

	/* If true, the goal will be displayed over the main play area. */
	int view_goal_on_game;

	/* Whether to set _NET_WM_ICON property on WMShell */
	int use_ewmh_icons;

	GC tile_gc;
	Pixmap icon_pixmap;
	uint_least32_t tile_colour[TILE_MAX-1][3];
};

void ui_initialize(struct app_state *state, Widget shell);
void x11_initialize(struct app_state *state, Widget shell);
void x11_redraw_icon(struct app_state *state, Widget shell);
void x11_redraw_goal(struct app_state *state, uint_fast32_t mask);
void x11_redraw_game(struct app_state *state, uint_fast32_t mask);

#endif
